@@ -3,15 +3,19 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import click
 import logging
 
+# WARNING: do not import unnecessary things here to keep cli startup time under
+# control
+import click
+
 from swh.core.cli import CONTEXT_SETTINGS
+from swh.core.cli import swh as swh_cli_group
 
 logger = logging.getLogger(__name__)
 
 
-@click.group(context_settings=CONTEXT_SETTINGS)
+@swh_cli_group.group(context_settings=CONTEXT_SETTINGS)
 @click.pass_context
 def deposit(ctx):
     """Deposit main command
