@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020  The Software Heritage developers
+# Copyright (C) 2017-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -6,7 +6,7 @@
 import copy
 import json
 
-from django.urls import reverse
+from django.urls import reverse_lazy as reverse
 from rest_framework import status
 
 from swh.deposit.api.private.deposit_update_status import MANDATORY_KEYS
